#' do_predict

#' do_predict
#' @param service service
#' @param model_path path to a model
#' @param model_id id of an internal model
#' @param dataset tibble or data.frame
#' @param col_bind col_bind in character
#' @keywords algoli
#' @export
#' @examples
#' \dontrun{
#' do_predict()
#' }
do_predict <- function(service,model_path=NULL,model_id=NULL,dataset=NULL,col_bind=NULL){

  fileCheck_path <- file.path(getwd(),"algoli")
  fileCheck_path <- normalizePath(fileCheck_path,mustWork = FALSE)
  dir.create(fileCheck_path, showWarnings = TRUE, recursive = TRUE)
  fileCheck <- file.path(fileCheck_path,"predict-check.log")
  file.create(fileCheck)

  # new algoli
  hello <- algoli::algdoor(service = service)

  # Connecting to session ...
  cat(c(as.character(Sys.time()),"connecting\n"), file=fileCheck,append=TRUE)
  hello$connect()

  # Incoporating dataset into session  ...
  cat(c(as.character(Sys.time()),"copying dataset\n"), file=fileCheck,append=TRUE)
  hello$dataset(dataset=dataset,col_bind= col_bind, train=0L,test=100L)

  # Loading the model ...
  cat(c(as.character(Sys.time()),"loading model\n"), file=fileCheck,append=TRUE)
  if (!is.null(model_path)) {
     res_fit <- hello$load_model(model_path)
  } else if (!is.null(model_id)){
       tmp <- dir_tmp_model(id=model_id)
       model_path <- file.path(tmp$model_path,"model.mod")
       res_fit <- hello$load_model(model_path)
  } else stop("Either model_path or model_id must non-null")


  # Prediction on the dataset ...
  cat(c(as.character(Sys.time()),"predict\n"), file=fileCheck,append=TRUE)
  res_pred <- hello$predict(res_fit)

  res <- list(pred = res_pred,
              id = model_id,
              path = model_path)

  # disconnect ...
  cat(c(as.character(Sys.time()),"disconnect\n"), file=fileCheck,append=TRUE)
  hello$disconnect()

  return(res)
}
